# -*- coding: utf-8 -*-
# Generated by Django 1.11.22 on 2019-07-03 15:26


import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bulk_grades', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scoreoverrider',
            name='module',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.CASCADE, to='courseware.StudentModule'),
        ),
    ]
